@@ -34,6 +34,14 @@ def test_escaped_spacelink():
     assert '<a href="http://cdent.tiddlyspace.org:8080/">@cdent</a>' not in output
     assert '@cdent' in output
 
+def test_bounded_spacelink():
+    tiddler = Tiddler('test')
+    tiddler.text = '# Hi\nVisit @cdent: for more info.'
+
+    output = render(tiddler, environ)
+
+    assert '<a href="http://cdent.tiddlyspace.org:8080/">@cdent</a>' in output
+    assert '@cdent' in output
 
 def test_spacelink_first():
     tiddler = Tiddler('test')
